@@ -24,7 +24,7 @@ class AuthCookieAuthentifier(native.BaseAuthentifier):
         rset = session.execute(self.auth_rql, {'login': login,
                                                'magicnumber': magicnumber})
         if rset:
-            session.repo.glob_delete_entity(session, rset[0][1])
+            session.repo.glob_delete_entities(session, [rset[0][1]])
             session.commit(reset_pool=False)
             return rset[0][0]
         raise AuthenticationError('bad password')
