@@ -92,8 +92,8 @@ class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
             return False
         return True
 
-    def revalidate_login(self):
-        cookie = self._cw.get_cookie()
+    def revalidate_login(self, req):
+        cookie = req.get_cookie()
         authcookie = cookie['__cw_auth_cookie'].value
         return authcookie.split('|__magic=', 1)[0]
 
@@ -101,7 +101,7 @@ class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
 # add remember me checkbox on the login form ###################################
 
 basetemplates.LogForm.append_field(
-    ff.BooleanField('__setauthcookie', choices=[(_('remember me'), u'1')],
+    ff.BooleanField(name='__setauthcookie', choices=[(_('remember me'), u'1')],
                     label=None, widget=fw.CheckBox({'class': 'data'}))
     )
 
